@@ -1,4 +1,24 @@
 import ast
+import json
+
+"""
+~Project
+Author: Kyshi (https://kyshi.github.io)
+License: MIT
+Version: 0.6
+Status: alpha
+Github: https://github.com/kyshi/NotiaDB
+
+~Features (version 0.6 | alpha)
+Added information section in main code.
+Added logical operations in filter().
+Added return dictionary feature in filter().
+Both dictionary and str taking feature added to update() (It used to take str only in dictionary form.)
+If in first line, writeNl() doesn't put newline character.
+Removed key parameter in update(), key will to be set by the key of kwargs now.
+Recommended parameter types set.
+Fixed bugs.
+"""
 
 
 class NotiaDB:
@@ -15,10 +35,11 @@ class NotiaDB:
             -readKeys: Reads only keys in the file
             -readValues: Reads only values in the file
             -readFile: Reads all the
-            -filter(key, value): Returns the dictionary with the desired key and value, returns a list if there is more than one value to return
+            -filter(key, conditions): Returns the dictionary with the desired key and value, returns a list if there is
+            more than one value to return
     """
 
-    def __init__(self, file_name, auto_id=False):
+    def __init__(self, file_name: str, auto_id: bool = False):
         self.name = file_name
         f = open(f"{self.name}.ndb", "a", encoding="utf8")
         f.close()
@@ -45,18 +66,24 @@ class NotiaDB:
             f.seek(0)
             f.seek(len(self.readFile()))
             if self.auto_id:
-                f.write("\n" + str(kwargs)[:1] + f"'id': {self.id}, " + str(kwargs)[1:])
+                if self.id != 1:  # If in first line
+                    f.write("\n" + str(kwargs)[:1] + f"'id': {self.id}, " + str(kwargs)[1:])
+                else:
+                    f.write(str(kwargs)[:1] + f"'id': {self.id}, " + str(kwargs)[1:])
                 self.id += 1
             else:
-                f.write("\n" + str(kwargs))
+                if f.readline() != "":  # If in first line
+                    f.write("\n" + str(kwargs))
+                else:
+                    f.write("\n" + str(kwargs))
 
-    def filter(self, key, value):
+    def filter(self, key: str or int, condition: str):
         with open(f"{self.name}.ndb", "r") as f:
             result = list()
-            datas = f.readlines()
-            for data in datas:
-                if ast.literal_eval(data)[key] == value:
-                    result.append(data)
+            all_data = f.readlines()
+            for data in all_data:
+                exec(f"if ast.literal_eval(data)[key] {condition.split(' ')[0]} {condition.split(' ')[1]}: "
+                     f"result.append(ast.literal_eval(data))")
             if len(result) > 1:
                 return result
             elif len(result) == 1:
@@ -66,9 +93,17 @@ class NotiaDB:
         with open(f"{self.name}.ndb", "w", encoding="utf8") as f:
             f.write(str(kwargs))
 
-    def update(self, data, key, **kwargs):
-        data = data
-        data_dict = ast.literal_eval(data)
+    def update(self, data: str or dict, **kwargs):
+        data_dict = dict()
+        key = list(kwargs.keys())[0]
+        if type(data) == str:
+            data = data
+            data_dict = ast.literal_eval(data)
+        elif type(data) == dict:
+            data_dict = data  # data already dict.
+            data = json.dumps(data)  # data converted dict.
+            # ! Tek tırnaklar çift tırnağa çevrilmedi
+            data = data.replace("\"", "$").replace("\'", "\"").replace("$", "'")  # Quotation marks corrected. Because break down place of quotation marks.
         file = self.readFile().split(data)
         with open(f"{self.name}.ndb", "w", encoding="utf8") as f:
             if type(data_dict[key]) == str:
@@ -86,7 +121,7 @@ class NotiaDB:
                 data_last = data[index + len(key) + 4 + len(str(data_dict[key])):]
                 f.write(f"{data_start}{kwargs[key]}{data_last}")
 
-    def read(self, key):
+    def read(self, key: str or int):
         with open(f"{self.name}.ndb", "r", encoding="utf8") as f:
             f.seek(0)
             if len(f.read()) > 0:
